pub enum OrderError {
InvalidBidFlipTick {
tick: i16,
flip_tick: i16,
},
InvalidAskFlipTick {
tick: i16,
flip_tick: i16,
},
NotAFlipOrder,
OrderNotFullyFilled {
remaining: u128,
},
FillAmountExceedsRemaining {
requested: u128,
available: u128,
},
InvalidTick {
tick: i16,
min: i16,
max: i16,
},
}Expand description
Errors that can occur when working with orders.
Variants
InvalidBidFlipTick
Flip tick constraint violated for a bid flip order. For bids: flip_tick must be > tick
InvalidAskFlipTick
Flip tick constraint violated for an ask flip order. For asks: flip_tick must be < tick
NotAFlipOrder
Attempted to create a flipped order from a non-flip order
OrderNotFullyFilled
Attempted to create a flipped order from an order that is not fully filled
FillAmountExceedsRemaining
Attempted to fill more than the remaining amount
InvalidTick
Tick value is out of valid bounds